==> jc-1.4.0.tar.gz: soot/jimple/parser/parser/State.h <==
// final class soot.jimple.parser.parser.State

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96a942623547e8d8 soot_jimple_parser_parser_State

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_parser_State_H_
#define _JC_soot_jimple_parser_parser_State_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_parser_State$sub_refs	_jc_soot_jimple_parser_parser_State$sub_refs;
typedef struct _jc_soot_jimple_parser_parser_State$sub_nonrefs	_jc_soot_jimple_parser_parser_State$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_parser_State$refs	_jc_soot_jimple_parser_parser_State$refs;
typedef struct _jc_soot_jimple_parser_parser_State$nonrefs	_jc_soot_jimple_parser_parser_State$nonrefs;
typedef struct _jc_soot_jimple_parser_parser_State$object	_jc_soot_jimple_parser_parser_State$object;

typedef const struct _jc_soot_jimple_parser_parser_State$vmethods	_jc_soot_jimple_parser_parser_State$vmethods;
typedef const struct _jc_soot_jimple_parser_parser_State$vtable	_jc_soot_jimple_parser_parser_State$vtable;
typedef const struct _jc_soot_jimple_parser_parser_State$vtype	_jc_soot_jimple_parser_parser_State$vtype;

// Constructors
extern void _jc_soot_jimple_parser_parser_State$method$_init$964b4a8e45252143(_jc_env *, struct _jc_soot_jimple_parser_parser_State$object *, jint, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_parser_State$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_parser_State$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_parser_State$vmethods	soot_jimple_parser_parser_State;
};

// Vtype
struct _jc_soot_jimple_parser_parser_State$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_parser_State$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_State$sub_refs {
	struct _jc_java_lang_Object$object	*node;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_parser_State$refs {
    _jc_soot_jimple_parser_parser_State$sub_refs	soot_jimple_parser_parser_State;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_State$sub_nonrefs {
	jint	state;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_parser_State$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_parser_State$sub_nonrefs	soot_jimple_parser_parser_State;
};

// Object instance structure
struct _jc_soot_jimple_parser_parser_State$object {
	_jc_soot_jimple_parser_parser_State$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_parser_State$vtype	*vtype;
	_jc_soot_jimple_parser_parser_State$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_parser_State$vtype _jc_soot_jimple_parser_parser_State$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_parser_State, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_parser_State$class_object;

#endif	/* _JC_soot_jimple_parser_parser_State_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/parser/State.h <==
// final class soot.jimple.parser.parser.State

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96a942623547e8d8 soot_jimple_parser_parser_State

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_parser_State_H_
#define _JC_soot_jimple_parser_parser_State_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_parser_State$sub_refs	_jc_soot_jimple_parser_parser_State$sub_refs;
typedef struct _jc_soot_jimple_parser_parser_State$sub_nonrefs	_jc_soot_jimple_parser_parser_State$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_parser_State$refs	_jc_soot_jimple_parser_parser_State$refs;
typedef struct _jc_soot_jimple_parser_parser_State$nonrefs	_jc_soot_jimple_parser_parser_State$nonrefs;
typedef struct _jc_soot_jimple_parser_parser_State$object	_jc_soot_jimple_parser_parser_State$object;

typedef const struct _jc_soot_jimple_parser_parser_State$vmethods	_jc_soot_jimple_parser_parser_State$vmethods;
typedef const struct _jc_soot_jimple_parser_parser_State$vtable	_jc_soot_jimple_parser_parser_State$vtable;
typedef const struct _jc_soot_jimple_parser_parser_State$vtype	_jc_soot_jimple_parser_parser_State$vtype;

// Constructors
extern void _jc_soot_jimple_parser_parser_State$method$_init$964b4a8e45252143(_jc_env *, struct _jc_soot_jimple_parser_parser_State$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_parser_State$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_parser_State$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_parser_State$vmethods	soot_jimple_parser_parser_State;
};

// Vtype
struct _jc_soot_jimple_parser_parser_State$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_parser_State$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_State$sub_refs {
	struct _jc_java_lang_Object$object	*node;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_parser_State$refs {
    _jc_soot_jimple_parser_parser_State$sub_refs	soot_jimple_parser_parser_State;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_State$sub_nonrefs {
	jint	state;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_parser_State$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_parser_State$sub_nonrefs	soot_jimple_parser_parser_State;
};

// Object instance structure
struct _jc_soot_jimple_parser_parser_State$object {
	_jc_soot_jimple_parser_parser_State$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_parser_State$vtype	*vtype;
	_jc_soot_jimple_parser_parser_State$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_parser_State$vtype _jc_soot_jimple_parser_parser_State$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_parser_State, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_parser_State$class_object;

#endif	/* _JC_soot_jimple_parser_parser_State_H_ */
